
*	**********************************************************************	*
*	This file replicates Table 1 of											*
*	Hollyer, James R., B. Peter Rosendorff, James Raymond Vreeland			*
*	Transparency, Protest, and Autocratic Instability						*
*	American Political Science Review										*
*	**********************************************************************	*

* Please change local DIR to your working directory:
*	**********************************************************************	*
local DIR = "C:\A\transpar\HRV_APSR_Replication_Materials\" 
cd "`DIR'" 
*	**********************************************************************	*

version 11

capture log close
clear
clear mata
clear matrix
set mem 500m
set more off
graph drop _all

log using "HRV_APSR_Table1.log", replace

use "HRV_APSR_Table1.dta", clear


*Data previously stset as: 
	*stset eyear, id(AutocRegimeID) origin(estartdate) failure(failrevolt) exit(failnotrevolt==1) scale(365.25)



*Table 1. Cox Models Autocrat Removal from Below

*Cond. Past Collapse: 
	*Model 1:
	stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_open lag_open2 lag_open3 lag_party lag_mil, nohr strata(ever_collapse) cluster(AutocRegimeID)
		estimates store revoltstability1
		estat phtest, rank detail
	*Model 2:
	stcox lag_transparency lag_growth lag_trans_growth lag_party lag_mil, nohr strata(ever_collapse) cluster(AutocRegimeID)
		estimates store revoltstability2
		estat phtest, rank detail
	*Model 3:
	stcox lag_transparency lag_growth lag_trans_growth, nohr strata(ever_collapse) cluster(AutocRegimeID)
		estimates store revoltstability3
		estat phtest, rank detail

*Cond. Hist. Instability: 
	*Model 4:
	stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_open lag_open2 lag_open3 lag_party lag_mil, nohr strata(hist_instability) cluster(AutocRegimeID)
		estimates store revoltstability4
		estat phtest, rank detail
	*Model 5:
	stcox lag_transparency lag_growth lag_trans_growth lag_party lag_mil, nohr strata(hist_instability) cluster(AutocRegimeID)
		estimates store revoltstability5
		estat phtest, rank detail
	*Model 6:
	stcox lag_transparency lag_growth lag_trans_growth, nohr strata(hist_instability) cluster(AutocRegimeID)
		estimates store revoltstability6
		estat phtest, rank detail

*Control Past Collapse
	*Model 7:
	stcox lag_transparency lag_growth lag_trans_growth lag_GDP lag_open lag_open2 lag_open3 lag_party lag_mil ever_collapse, nohr cluster(AutocRegimeID)
		estimates store revoltstability7
		estat phtest, rank detail
	*Model 8:
	stcox lag_transparency lag_growth lag_trans_growth lag_party lag_mil ever_collapse, nohr cluster(AutocRegimeID)
		estimates store revoltstability8
		estat phtest, rank detail
	*Model 9:
	stcox lag_transparency lag_growth lag_trans_growth ever_collapse, nohr cluster(AutocRegimeID)
		estimates store revoltstability9
		estat phtest, rank detail

*Table 1 output in TeX:
	estout revoltstability1 revoltstability2 revoltstability3 revoltstability4 revoltstability5 revoltstability6 revoltstability7 revoltstability8 revoltstability9 using "HRV_APSR_Table1.tex", cells(b(star fmt(3)) ci(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N_clust N_fail, labels("\# of Subjects" "\# of Failures")) style(tex) replace

*Figure 4: Hazard Rates as a Function of Transparency and Growth (based on Model 8):
	stcox lag_transparency lag_growth lag_trans_growth lag_party lag_mil ever_collapse, nohr cluster(AutocRegimeID)

drawnorm b1 b2 b3 b4 b5 b6, means(e(b)) cov(e(V))
sum transparencyindex, detail

local translow=r(p10)

local transhigh=r(p90)

sum grgdpch, detail

local growthlow=r(p10)
local growthhigh=r(p90)

local lowlowint=`translow'*`growthlow'
local lowhighint=`translow'*`growthhigh'

gen xb_low_low=.
gen xb_low_high=.
gen xb_high_low=.
gen xb_high_high=.

replace xb_low_low = b1*`translow' + b2*`growthlow' + b3*`lowlowint' + b6
replace xb_low_high = b1*`translow' + b2*`growthhigh' + b3*`lowhighint' +b6

stcurve, hazard at1(lag_transparency=`translow' lag_growth=`growthlow' lag_trans_growth=`lowlowint' lag_party=0 lag_mil=0 ever_collapse=1) at2(lag_transparency=`translow' lag_growth=`growthhigh' lag_trans_growth=`lowhighint' lag_party=0 lag_mil=0 ever_collapse=1) graphregion(fcolor(white)) ytitle(Hazard Rate) xtitle(Spell Length - Years) scheme(s2mono) legend(label(1 Low Growth) label(2 High Growth)) title(Low Transparency) name(lowtrans, replace) yscale(range(0 .06)) ymtick(0(.01).06)

local highlowint=`transhigh'*`growthlow'
local highhighint=`transhigh'*`growthhigh'

replace xb_high_low = b1*`transhigh' + b2*`growthlow' + b3*`highlowint' + b6
replace xb_high_high = b1*`transhigh' + b2*`growthhigh' + b3*`highhighint' + b6

stcurve, hazard at1(lag_transparency=`transhigh' lag_growth=`growthlow' lag_trans_growth=`highlowint' lag_party=0 lag_mil=0 ever_collapse=1) at2(lag_transparency=`transhigh' lag_growth=`growthhigh' lag_trans_growth=`highhighint' lag_party=0 lag_mil=0 ever_collapse=1) graphregion(fcolor(white)) ytitle(Hazard Rate) xtitle(Spell Length - Years) scheme(s2mono) legend(label(1 Low Growth) label(2 High Growth)) title(High Transparency) name(hightrans, replace) yscale(range(0 .06)) ymtick(0(.01).06)

graph combine lowtrans hightrans, ycommon graphregion(fcolor(white)) title(Cox Hazard Estimates) 

graph export "Figure4.png", width(1000) replace


log close
