
*	**********************************************************************	*
*	This file replicates Tables 3 & 4 of											*
*	Hollyer, James R., B. Peter Rosendorff, James Raymond Vreeland			*
*	Transparency, Protest, and Autocratic Instability						*
*	American Political Science Review										*
*	**********************************************************************	*

* Please change local DIR to your working directory:
*	**********************************************************************	*
local DIR = "C:\A\transpar\HRV_APSR_Replication_Materials\" 
cd "`DIR'" 
*	**********************************************************************	*

version 11

capture log close
clear
clear mata
clear matrix
set mem 500m
set more off
graph drop _all

log using "HRV_APSR_Tables_3_&_4.log", replace

use "HRV_APSR_Tables_3_&_4", clear

*Table 3. Fixed-Effects Negative Binomial Models, Unrest

*General Strikes
xtnbreg GenStrikes L.GenStrikes L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.openk L.lparty_alt L.nmil oil t t2 t3  if democracy==0, fe
	estimates store unrest1
*Riots
xtnbreg Riots L.Riots L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.openk L.lparty_alt L.nmil oil t t2 t3  if democracy==0, fe technique(dfp) 
	estimates store unrest2
*Demonstrations
xtnbreg AntiGovDem L.AntiGovDem L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.openk L.lparty_alt L.nmil oil t t2 t3  if democracy==0, fe technique(dfp)
	estimates store unrest3
*Revolutions
xtnbreg Revolutions L.Revolutions L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.openk L.lparty_alt L.nmil oil t t2 t3  if democracy==0, fe technique(dfp) 
	estimates store unrest4
*Guerilla
xtnbreg Guerilla L.Guerilla L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.openk L.lparty_alt L.nmil oil t t2 t3  if democracy==0, fe technique(dfp)
	estimates store unrest5
*Coups
xtnbreg Coups L.Coups L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.openk L.lparty_alt L.nmil oil t t2 t3  if democracy==0, fe technique(bfgs)
	estimates store unrest6
*Assassinations
xtnbreg Assinations L.Assinations L.transparencyindex L.grgdpch L.trans_growth L.rgdpch L.openk L.lparty_alt L.nmil oil t t2 t3  if democracy==0, fe technique(dfp)
	estimates store unrest7

estout unrest1 unrest2 unrest3 unrest4 unrest5 unrest6 unrest7 using "HRV_APSR_Table3.tex", cells(b(star fmt(3)) ci(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N N_g, labels("\#Obs" "\#Countries")) style(tex) replace 


*Table 4. Fixed-Effects Negative Binomial Models, Unrest

*General Strikes
xtnbreg GenStrikes L.GenStrikes L.transparencyindex L.grgdpch L.trans_growth if democracy==0, fe
	estimates store unrestsimp1
*Riots
xtnbreg Riots L.Riots L.transparencyindex L.grgdpch L.trans_growth if democracy==0, fe technique(dfp)
	estimates store unrestsimp2
*Demonstrations
xtnbreg AntiGovDem L.AntiGovDem L.transparencyindex L.grgdpch L.trans_growth if democracy==0, fe technique(dfp)
	estimates store unrestsimp3
*Revolutions
xtnbreg Revolutions L.Revolutions L.transparencyindex L.grgdpch L.trans_growth if democracy==0, fe technique(dfp)
	estimates store unrestsimp4
*Guerilla
xtnbreg Guerilla L.Guerilla L.transparencyindex L.grgdpch L.trans_growth if democracy==0, fe technique(dfp)
	estimates store unrestsimp5
*Coups
xtnbreg Coups L.Coups L.transparencyindex L.grgdpch L.trans_growth if democracy==0, fe technique(bfgs)
	estimates store unrestsimp6
*Assassinations
xtnbreg Assinations L.Assinations L.transparencyindex L.grgdpch L.trans_growth if democracy==0, fe technique(dfp)
	estimates store unrestsimp7

estout unrestsimp1 unrestsimp2 unrestsimp3 unrestsimp4 unrestsimp5 unrestsimp6 unrestsimp7 using "HRV_APSR_Table4.tex", cells(b(star fmt(3)) ci(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N N_g, labels("\#Obs" "\#Countries")) style(tex) replace

log close
